Forgot Username
===============
App for a user who forgot their username.

Flow
====
1. Navigate to the forgot username page
2. The user enters their email address
3. An email is sent to the user telling them their username